const helpers = require('./helpers')
const mailService = require('pubsweet-component-mail-service')
const logger = require('@pubsweet/logger')
const collectionHelper = require('./Collection')

const setupNewUser = async (
  body,
  url,
  res,
  email,
  role,
  UserModel,
  invitationType,
) => {
  const { firstName, lastName, affiliation, title } = body
  const newUser = await helpers.createNewUser(
    email,
    firstName,
    lastName,
    affiliation,
    title,
    UserModel,
    role,
  )

  try {
    if (role !== 'reviewer') {
      await mailService.setupInviteEmail(newUser, invitationType, url)
    }

    return newUser
  } catch (e) {
    logger.error(e.message)
    return { status: 500, error: 'Email could not be sent.' }
  }
}

const getEditorInChief = async UserModel => {
  const users = await UserModel.all()
  const eic = users.find(user => user.editorInChief === true)
  return eic
}

const setupReviewerDecisionEmailData = async ({
  baseUrl,
  UserModel,
  FragmentModel,
  collection,
  reviewerName,
  mailService,
  agree,
  timestamp = Date.now(),
}) => {
  const {
    title,
    authorName,
    id,
  } = await collectionHelper.getFragmentAndAuthorData({
    UserModel,
    FragmentModel,
    collection,
  })
  const eic = await getEditorInChief(UserModel)
  const toEmail = collection.handlingEditor.email
  await mailService.setupReviewerDecisionEmail({
    toEmail,
    reviewerName,
    collection,
    eicName: `${eic.firstName} ${eic.lastName}`,
    baseUrl,
    fragment: { id, title, authorName },
    agree,
    timestamp,
  })
}

const setupReviewerUnassignEmail = async ({
  UserModel,
  FragmentModel,
  collection,
  user,
  mailService,
}) => {
  const { title, authorName } = await collectionHelper.getFragmentAndAuthorData(
    {
      UserModel,
      FragmentModel,
      collection,
    },
  )

  await mailService.setupReviewerUnassignEmail(
    user,
    collection,
    title,
    authorName,
  )
}

module.exports = {
  setupNewUser,
  getEditorInChief,
  setupReviewerDecisionEmailData,
  setupReviewerUnassignEmail,
}
