const logger = require('@pubsweet/logger')
const helpers = require('../../helpers/helpers')
const teamHelper = require('../../helpers/Team')
const mailService = require('pubsweet-component-mail-service')
const userHelper = require('../../helpers/User')
const collectionHelper = require('../../helpers/Collection')

module.exports = models => async (req, res) => {
  const { collectionId, invitationId } = req.params
  const { isAccepted, reason } = req.body

  if (!helpers.checkForUndefinedParams(isAccepted)) {
    res.status(400).json({ error: 'Missing parameters.' })
    logger.error('some parameters are missing')
    return
  }
  let user = await models.User.find(req.user)
  try {
    const collection = await models.Collection.find(collectionId)
    const invitation = await collection.invitations.find(
      invitation => invitation.id === invitationId,
    )
    if (invitation === undefined)
      return res.status(404).json({
        error: 'Invitation not found.',
      })
    if (invitation.hasAnswer)
      return res
        .status(400)
        .json({ error: 'Invitation has already been answered.' })
    if (invitation.userId !== user.id)
      return res.status(403).json({
        error: `User is not allowed to modify this invitation.`,
      })

    const params = {
      baseUrl: helpers.getBaseUrl(req),
      UserModel: models.User,
      FragmentModel: models.Fragment,
      collection,
      reviewerName: `${user.firstName} ${user.lastName}`,
      mailService,
    }
    if (invitation.role === 'handlingEditor')
      await collectionHelper.updateHandlingEditor(collection, isAccepted)
    invitation.respondedOn = Date.now()
    invitation.hasAnswer = true
    const eic = await userHelper.getEditorInChief(models.User)
    const toEmail = eic.email
    if (isAccepted === true) {
      invitation.isAccepted = true
      if (
        invitation.role === 'reviewer' &&
        collection.status === 'reviewersInvited'
      )
        await collectionHelper.updateStatus(collection, 'underReview')

      await collection.save()
      try {
        if (invitation.role === 'handlingEditor')
          await mailService.setupAgreeEmail(
            toEmail,
            user,
            invitation.role,
            `${req.protocol}://${req.get('host')}`,
            collection.customId,
          )
        if (invitation.role === 'reviewer')
          await userHelper.setupReviewerDecisionEmailData({
            ...params,
            agree: true,
            timestamp: invitation.respondedOn,
          })
        return res.status(200).json(invitation)
      } catch (e) {
        logger.error(e)
        return res.status(500).json({ error: 'Email could not be sent.' })
      }
    } else {
      invitation.isAccepted = false

      if (invitation.role === 'handlingEditor')
        await teamHelper.updateHETeam(
          collection,
          invitation.role,
          models.Team,
          user,
        )
      if (reason !== undefined) {
        invitation.reason = reason
        await collection.save()
      }
      try {
        if (invitation.role === 'handlingEditor') {
          await mailService.setupDeclineEmail(
            toEmail,
            user,
            'handling-editor-declined',
            collection.customId,
            reason,
          )
        } else if (invitation.role === 'reviewer') {
          await collectionHelper.updateReviewerCollectionStatus(collection)
          await userHelper.setupReviewerDecisionEmailData({
            ...params,
            agree: false,
          })
        }
      } catch (e) {
        logger.error(e)
        return res.status(500).json({ error: 'Email could not be sent.' })
      }
    }
    user = await user.save()
    return res.status(200).json(invitation)
  } catch (e) {
    const notFoundError = await helpers.handleNotFoundError(e, 'collection')
    return res.status(notFoundError.status).json({
      error: notFoundError.message,
    })
  }
}
