const querystring = require('querystring')
const fs = require('fs')
const handlebars = require('handlebars')

const createUrl = (baseUrl, slug, queryParams = null) =>
  !queryParams
    ? `${baseUrl}${slug}`
    : `${baseUrl}${slug}?${querystring.encode(queryParams)}`

const getEmailBody = (emailType, replacements) => {
  const htmlFile = readFile(`${__dirname}/../templates/${emailType}.html`)
  const textFile = readFile(`${__dirname}/../templates/${emailType}.txt`)
  const htmlTemplate = handlebars.compile(htmlFile)
  const textTemplate = handlebars.compile(textFile)
  const htmlBody = htmlTemplate(replacements)
  const textBody = textTemplate(replacements)
  return { htmlBody, textBody }
}

const readFile = path =>
  fs.readFileSync(path, { encoding: 'utf-8' }, (err, file) => {
    if (err) {
      throw err
    } else {
      return file
    }
  })

const getExpectedDate = (timestamp, daysExpected) => {
  const date = new Date(timestamp)
  let expectedDate = date.getDate() + daysExpected
  date.setDate(expectedDate)
  expectedDate = date.toLocaleDateString('en-US', {
    day: 'numeric',
    month: 'long',
    year: 'numeric',
  })
  return expectedDate
}

module.exports = { createUrl, getEmailBody, getExpectedDate }
