const helpers = require('../../helpers/helpers')
const authsomeHelper = require('../../helpers/authsome')
const collectionHelper = require('../../helpers/Collection')

module.exports = models => async (req, res) => {
  const { collectionId, fragmentId, recommendationId } = req.params
  let collection, fragment
  try {
    collection = await models.Collection.find(collectionId)
    if (!collection.fragments.includes(fragmentId))
      return res.status(400).json({
        error: `Collection and fragment do not match.`,
      })
    const authsome = authsomeHelper.getAuthsome(models)
    const target = {
      collection,
      path: req.route.path,
    }
    const canPatch = await authsome.can(req.user, 'PATCH', target)
    if (!canPatch)
      return res.status(403).json({
        error: 'Unauthorized.',
      })
    fragment = await models.Fragment.find(fragmentId)
    const recommendation = fragment.recommendations.find(
      rec => rec.id === recommendationId,
    )
    if (!recommendation)
      return res.status(404).json({ error: 'Recommendation not found.' })
    if (recommendation.userId !== req.user)
      return res.status(403).json({
        error: 'Unauthorized.',
      })
    Object.assign(recommendation, req.body)
    recommendation.updatedOn = Date.now()
    if (req.body.submittedOn !== undefined)
      await collectionHelper.updateStatus(collection, 'reviewCompleted')
    await fragment.save()
    return res.status(200).json(recommendation)
  } catch (e) {
    const notFoundError = await helpers.handleNotFoundError(e, 'Item')
    return res.status(notFoundError.status).json({
      error: notFoundError.message,
    })
  }
}
