import React from 'react'
import { th } from '@pubsweet/ui'
import styled from 'styled-components'

const TR = ({
  name,
  email,
  affiliation,
  isSubmitting,
  isCorresponding,
  index,
}) => (
  <Row>
    <td width="20">{index + 1}</td>
    <td>
      <AuthorName>{name}</AuthorName>
      {isSubmitting && <AuthorStatus>SA</AuthorStatus>}
      {isCorresponding && !isSubmitting && <AuthorStatus>CA</AuthorStatus>}
    </td>
    <td>{email || ''}</td>
    <td>{affiliation}</td>
  </Row>
)

const Authors = ({ authors }) => (
  <Table>
    <thead>
      <tr>
        <td colSpan="2">Full Name</td>
        <td>{authors[0].email ? 'Email' : ''}</td>
        <td>Affiliation</td>
      </tr>
    </thead>
    <tbody>
      {authors.map(
        (
          {
            userId,
            firstName = '',
            lastName = '',
            email = '',
            affiliation = '',
            isCorresponding,
            isSubmitting,
          },
          index,
        ) => (
          <TR
            affiliation={affiliation}
            email={email}
            index={index}
            isCorresponding={isCorresponding}
            isSubmitting={isSubmitting}
            key={`${userId}`}
            name={`${firstName} ${lastName}`}
          />
        ),
      )}
    </tbody>
  </Table>
)

export default Authors

// #region styled-components
const Row = styled.tr`
  border-bottom: ${th('borderDefault')};
  color: ${th('colorPrimary')};
  font-family: ${th('fontReading')};
  font-size: ${th('fontSizeBaseSmall')};
  height: 40px;
  text-align: left;
  td:first-child {
    font-weight: bold;
  }
  &:hover {
    background-color: ${th('backgroundColorReverse')};
  }
`

const AuthorName = styled.span`
  text-decoration: underline;
`

const AuthorStatus = styled.span`
  border: ${th('borderDefault')};
  font-family: ${th('fontReading')};
  font-size: ${th('fontSizeBaseSmall')};
  text-align: center;
  text-transform: uppercase;
  padding: 0 2px;
  margin-left: 4px;
`

const Table = styled.table`
  border-spacing: 0;
  border-collapse: collapse;
  width: 100%;

  & thead tr {
    border-bottom: ${th('borderDefault')};
    color: ${th('colorPrimary')};
    font-family: ${th('fontReading')};
    font-size: ${th('fontSizeBaseSmall')};
    font-weight: bold;
    height: 40px;
    text-align: left;
  }
`

// #endregion
