import React, { Fragment } from 'react'
import styled, { css } from 'styled-components'
import { th } from '@pubsweet/ui'

import { FileItem } from 'pubsweet-components-faraday/src/components/Files'

const Files = ({
  files: { manuscripts = [], coverLetter = [], supplementary = [] },
}) => (
  <Root>
    {!!manuscripts.length && (
      <Fragment>
        <Header>
          <span>Main manuscript</span>
          <div />
        </Header>
        {manuscripts.map(file => (
          <FileItem compact id={file.id} key={file.id} {...file} />
        ))}
      </Fragment>
    )}
    {!!supplementary.length && (
      <Fragment>
        <Header>
          <span>Supplemetary files</span>
          <div />
        </Header>
        {supplementary.map(file => (
          <FileItem compact id={file.id} key={file.id} {...file} />
        ))}
      </Fragment>
    )}
    {!!coverLetter.length && (
      <Fragment>
        <Header>
          <span>Cover letter</span>
          <div />
        </Header>
        {coverLetter.map(file => (
          <FileItem compact id={file.id} key={file.id} {...file} />
        ))}
      </Fragment>
    )}
  </Root>
)

export default Files

// #region styled-component
const defaultText = css`
  color: ${th('colorPrimary')};
  font-family: ${th('fontHeading')};
  font-size: ${th('fontSizeBaseSmall')};
`

const Header = styled.div`
  align-self: stretch;
  align-items: center;
  display: flex;
  flex-direction: row;

  & span {
    margin-right: ${th('subGridUnit')};
    ${defaultText};
    margin-top: ${th('subGridUnit')};
    text-transform: uppercase;
  }

  & div {
    background: ${th('colorPrimary')};
    flex: 1;
    height: 1px;
  }
`

const Root = styled.div`
  align-items: flex-start;
  display: flex;
  flex-direction: column;
  justify-content: flex-start;
`
// #endregion
