import React from 'react'

import ManuscriptHeader from './ManuscriptHeader'
import ManuscriptVersion from './ManuscriptVersion'
import {
  Root,
  BreadCrumbs,
  Header,
  ManuscriptId,
  Container,
  SideBar,
  LeftDetails,
  RightDetails,
} from '../atoms'
import {
  ManuscriptDetails,
  SideBarActions,
  SideBarRoles,
  ReviewsAndReports,
} from './'

const ManuscriptLayout = ({
  project,
  version,
  journal,
  history,
  currentUser,
  currentUserIs,
  editorInChief,
  updateManuscript,
}) => (
  <Root>
    <Container flex={3}>
      <Header>
        <LeftDetails>
          <BreadCrumbs>
            <span onClick={() => history.push('/')}>Dashboard</span>
            <span>Manuscript Details</span>
          </BreadCrumbs>
          <ManuscriptId>{`- ID ${project.customId}`}</ManuscriptId>
        </LeftDetails>
        <RightDetails>
          <ManuscriptVersion project={project} />
        </RightDetails>
      </Header>
      <ManuscriptHeader journal={journal} project={project} version={version} />
      <ManuscriptDetails collection={project} fragment={version} />
      <ReviewsAndReports
        currentUserIs={currentUserIs}
        project={project}
        version={version}
      />
    </Container>
    <SideBar flex={1}>
      <SideBarActions
        currentUserIs={currentUserIs}
        project={project}
        version={version}
      />
      <SideBarRoles
        currentUser={currentUser}
        editorInChief={editorInChief}
        project={project}
        version={version}
      />
    </SideBar>
  </Root>
)

export default ManuscriptLayout
