import React, { Fragment } from 'react'
import { head } from 'lodash'
import { th } from '@pubsweet/ui'
import { connect } from 'react-redux'
import styled from 'styled-components'
import { compose, withHandlers, lifecycle, withProps } from 'recompose'
import { ReviewerBreakdown } from 'pubsweet-components-faraday/src/components/Invitations'
import ReviewersDetailsList from 'pubsweet-components-faraday/src/components/Reviewers/ReviewersDetailsList'
import ReviewerReportForm from 'pubsweet-component-manuscript/src/components/ReviewerReportForm'
import {
  selectReviewers,
  selectFetchingReviewers,
  getCollectionReviewers,
  currentUserIsReviewer,
} from 'pubsweet-components-faraday/src/redux/reviewers'
import { selectRecommendations } from 'pubsweet-components-faraday/src/redux/recommendations'

import Tabs from '../molecules/Tabs'
import Expandable from '../molecules/Expandable'

const getTabSections = (collectionId, reviewers) => [
  {
    key: 1,
    label: 'Reviewers Details',
    content: (
      <ReviewersDetailsList collectionId={collectionId} reviewers={reviewers} />
    ),
  },
  {
    key: 2,
    label: 'Reviewer Reports',
    content: <div>Reviewer Reports Content</div>,
  },
]

const ReviewsAndReports = ({
  project,
  version,
  reviewers = [],
  recommendations = [],
  isReviewer,
  currentUserIs,
  report,
  review = {},
}) => (
  <Fragment>
    {currentUserIs('staff') && (
      <Root>
        <Expandable
          label="Reviewers & Reports"
          rightHTML={
            <ReviewerBreakdown type="reviewer" values={reviewers || []} />
          }
          startExpanded
        >
          <Tabs
            activeKey={1}
            sections={getTabSections(project.id, reviewers)}
          />
        </Expandable>
      </Root>
    )}
    {isReviewer && (
      <Root id="review-report">
        <Expandable label="Your Report" startExpanded>
          {report ? (
            <div>
              You have a submitted report with recommendation{' '}
              {report.recommendation}
            </div>
          ) : (
            <ReviewerReportForm
              project={project}
              review={review}
              version={version}
            />
          )}
        </Expandable>
      </Root>
    )}
  </Fragment>
)

export default compose(
  connect(
    (state, { project }) => ({
      reviewers: selectReviewers(state),
      recommendations: selectRecommendations(state),
      fetchingReviewers: selectFetchingReviewers(state),
      isReviewer: currentUserIsReviewer(state, project.id),
    }),
    { getCollectionReviewers },
  ),
  withHandlers({
    getReviewers: ({ project, getCollectionReviewers }) => () => {
      getCollectionReviewers(project.id)
    },
  }),
  withProps(({ recommendations = [] }) => ({
    report: head(recommendations.filter(r => r.submittedOn)),
    review: head(recommendations),
  })),
  lifecycle({
    componentDidMount() {
      const { getReviewers } = this.props
      getReviewers()
    },
  }),
)(ReviewsAndReports)

// #region styled-components

const Root = styled.div`
  background-color: ${th('colorBackground')};
  border: ${th('borderDefault')};
  margin-top: calc(${th('subGridUnit')} * 2);
  transition: height 0.3s;
`

// #endregion
