import React from 'react'
import { compose, withHandlers } from 'recompose'
import { Icon, Button, th, Spinner } from '@pubsweet/ui'
import styled, { css, withTheme } from 'styled-components'

const ConfirmationModal = ({
  title,
  subtitle,
  content,
  onConfirm,
  onClose,
  confirmText = 'OK',
  cancelText = 'Cancel',
  theme,
  modalError,
  isFetching,
}) => (
  <Root>
    <CloseIcon data-test="icon-modal-hide" onClick={onClose}>
      <Icon color={theme.colorPrimary}>x</Icon>
    </CloseIcon>
    {title && <Title dangerouslySetInnerHTML={{ __html: title }} />}
    {subtitle && <Subtitle dangerouslySetInnerHTML={{ __html: subtitle }} />}
    {content && <Content dangerouslySetInnerHTML={{ __html: content }} />}

    {modalError && <ErrorMessage>{modalError}</ErrorMessage>}

    <ButtonsContainer>
      <Button data-test="button-modal-hide" onClick={onClose}>
        {cancelText}
      </Button>
      {onConfirm &&
        (isFetching ? (
          <SpinnerContainer>
            <Spinner size={4} />
          </SpinnerContainer>
        ) : (
          <Button data-test="button-modal-confirm" onClick={onConfirm} primary>
            {confirmText}
          </Button>
        ))}
    </ButtonsContainer>
  </Root>
)

export default compose(
  withTheme,
  withHandlers({
    onClose: ({ onCancel, hideModal }) => () => {
      if (onCancel && typeof onCancel === 'function') {
        onCancel()
      } else {
        hideModal()
      }
    },
  }),
)(ConfirmationModal)

// #region styled-components
const defaultText = css`
  color: ${th('colorText')};
  font-family: ${th('fontReading')};
  font-size: ${th('fontSizeBaseSmall')};
`

const SpinnerContainer = styled.div`
  align-items: center;
  display: flex;
  justify-content: center;
  height: calc(${th('gridUnit')} * 2);
  min-width: calc(${th('gridUnit')} * 4);
`

const Root = styled.div`
  background-color: ${th('backgroundColor')};
  border: ${th('borderDefault')};
  display: flex;
  flex-direction: column;
  justify-content: space-between;
  max-height: calc(${th('gridUnit')} * 20);
  padding: calc(${th('gridUnit')} * 2);
  position: relative;
  overflow-y: scroll;
  width: calc(${th('gridUnit')} * 25);
`

const Title = styled.div`
  ${defaultText};
  font-size: ${th('fontSizeHeading5')};
  margin-bottom: ${th('gridUnit')};
  text-align: center;
`

const Subtitle = styled.div`
  ${defaultText};
  margin-bottom: calc(${th('subGridUnit')} * 6);
  text-align: center;
`

const Content = styled.div`
  ${defaultText};
  margin-top: calc(${th('subGridUnit')} * 2);
  text-align: left;
`
const ButtonsContainer = styled.div`
  display: flex;
  justify-content: space-evenly;
  margin: ${th('gridUnit')} auto 0;
  width: 100%;
`
const CloseIcon = styled.div`
  cursor: pointer;
  position: absolute;
  top: ${th('subGridUnit')};
  right: ${th('subGridUnit')};
`

const ErrorMessage = styled.div`
  color: ${th('colorError')};
  margin: ${th('subGridUnit')};
  text-align: center;
`

// #endregion
